<!DOCTYPE html>
<html>
  <head>
    <meta charset='utf-8'/>
    <title>{{title}}</title>
    <link rel="stylesheet" type="text/css" href="/static/github.min.css" />
  </head>
  <body>
    <div class="container">
      <div id="markup">
        <article id="content" class="markdown-body" data-timestamp="{{timestamp}}">
          {{!html_part}}
        </article>
      </div>
    </div>
  </body>
  <script type="text/javascript" src="/static/ender.min.js"></script>
  <script type="text/javascript" src="/static/app.js"></script>
</html>
